package com.ruoyi.system.service;

import com.ruoyi.system.domain.ActSupplies;
import io.lettuce.core.dynamic.annotation.Param;

import java.util.List;

/**
 * 物料总分类管理Service接口
 * 
 * @author ruoyi
 * @date 2023-07-11
 */

public interface IActSuppliesService 
{
    /**
     * 查询物料总分类管理
     * 
     * @param id 物料总分类管理ID
     * @return 物料总分类管理
     */
     ActSupplies selectActSuppliesById(Long id);

    /**
     * 查询物料总分类管理列表
     * 
     * @param actSupplies 物料总分类管理
     * @return 物料总分类管理集合
     */
     List<ActSupplies> selectActSuppliesList(ActSupplies actSupplies);

    /**
     * 新增物料总分类管理
     * 
     * @param actSupplies 物料总分类管理
     * @return 结果
     */
     int insertActSupplies(ActSupplies actSupplies);

    /**
     * 修改物料总分类管理
     * 
     * @param actSupplies 物料总分类管理
     * @return 结果
     */
     int updateActSupplies(ActSupplies actSupplies);

    /**
     * 批量删除物料总分类管理
     * 
     * @param ids 需要删除的物料总分类管理ID
     * @return 结果
     */
     int deleteActSuppliesByIds(Long[] ids);

    /**
     * 删除物料总分类管理信息
     * 
     * @param id 物料总分类管理ID
     * @return 结果
     */
     int deleteActSuppliesById(Long id);

    List<ActSupplies> options();

    /**
     * 启用物料细分类管理
     *
     * @param id  尝试启用物料细分类管理的id
     * @return
     */
    int setEnable(@Param("id") Long id, @Param("status") Integer status);


    /**
     * 禁用
     *
     * @param id  尝试禁用物料细分类管理的id
     */
    int setDisable(@Param("id") Long id, @Param("status") Integer status);

    List<Integer> find(Long id);

    List<Integer> findId(Long id);

}
